.. _tutorial:

Tutorial
========

Welcome to tutorial. The tutorial will explain how to use Django RPC application,
how it works and how can you implement what you wish. We will create some real application,
Result you can find in `our repo <https://github.com/Alerion/Django-RPC>`_.

This tutorial assumes you have created some Django project and installed ``rpc`` application;
if not see :ref:`installation instructions <installation>`.

.. toctree::
   :maxdepth: 2

   part1
   part2
   part3
   part4
